Actions class

Actions Clerk object

Annotations
  • @immutable
  • @JsonSerializable.new()

Constructors

Actions({bool deleteSelf = false, bool createOrganization = false, int? createOrganizationsLimit = 0})
Constructor
const

Properties

createOrganization bool
can user create organization?
final
createOrganizationsLimit int?
how many organizations can use create?
final
deleteSelf bool
can user delete self?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJson
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) Actions
create Actions from Json

Constants

empty → const Actions
empty Actions