Strategy class

Strategy Clerk object

A Strategy has a name. The various oAuth strategies ('oauth', 'oauth_token' and 'oauth_custom') also have a provider

Annotations
  • @immutable

Constructors

Strategy({required String name, String? provider})
Constructor for Strategy
const
Strategy.fromJson(String name)
fromJson - a factory
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
is email link?
no setter
isEnterpriseSSO bool
is Enterprise SSO?
no setter
isKnown bool
is known?
no setter
isOauth bool
is some variety of oauth?
no setter
isOauthCustom bool
is oauth custom?
no setter
isOauthToken bool
is oauth token?
no setter
isOtherStrategy bool
is other strategy?
no setter
isPasskey bool
is passkey?
no setter
isPassword bool
is password?
no setter
isPasswordResetter bool
is a password reset strategy?
no setter
isPhone bool
is phone strategy?
no setter
isSSO bool
is SSO?
no setter
isUnknown bool
is unknown?
no setter
name String
name
final
provider String?
provider
final
requiresCode bool
requires code?
no setter
requiresExternalAction bool
requires user to take some action outside of the app?
no setter
requiresNumericalCode bool
requires six digit code?
no setter
requiresPassword bool
requires password?
no setter
requiresPreparation bool
requires preparation?
no setter
requiresRedirect bool
requires redirect?
no setter
requiresSignature bool
requires signature?
no setter
requiresTextualCode bool
requires textual code?
no setter
requiresVerification bool
required verification?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

mightAccept(String? code) bool
Is this code acceptable for validation against the Frontend API?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toJson
toString() String
toJson
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

identificationStrategies Map<String, Strategy>
the collected identification strategies
final
oauthStrategies Map<String, Strategy>
the collected oauth strategies
final
secondaryAuthenticationStrategies Map<String, Strategy>
the collected secondary authentication strategies
final
verificationStrategies Map<String, Strategy>
the collected verification strategies
final

Static Methods

forUserAttribute(UserAttribute attr) Strategy
For a given UserAttribute, return an appropriate Strategy, or throw an error
named(dynamic name) Strategy?
For a given name return the Strategy it identifies. Create one if necessary and possible

Constants

admin → const Strategy
admin strategy
backupCode → const Strategy
backup code strategy
emailAddress → const Strategy
email address strategy
emailCode → const Strategy
email code strategy
email link strategy
enterpriseSSO → const Strategy
enterprise sso strategy
numericalCodeLength → const int
The length of a numerical code
oauthApple → const Strategy
oauth apple strategy
oauthFacebook → const Strategy
oauth facebook strategy
oauthGithub → const Strategy
oauth github strategy
oauthGoogle → const Strategy
oauth google strategy
oauthNotion → const Strategy
oauth notion strategy
oauthTiktok → const Strategy
oauth tiktok strategy
oauthTokenApple → const Strategy
oauth token apple strategy
oauthTokenGoogle → const Strategy
google authentication token strategy (google one tap)
oauthVercel → const Strategy
oauth vercel strategy
oauthX → const Strategy
oauth twitter strategy
passkey → const Strategy
passkey strategy
password → const Strategy
password strategy
phoneCode → const Strategy
phone code strategy
phoneNumber → const Strategy
phone number strategy
resetPasswordEmailCode → const Strategy
reset password email code strategy
resetPasswordPhoneCode → const Strategy
reset password phone code strategy
saml → const Strategy
saml strategy
textualCodeLength → const int
The length of a backup code
ticket → const Strategy
ticket strategy
totp → const Strategy
totp strategy
unknown → const Strategy
unknown strategy
username → const Strategy
username strategy
web3CoinbaseSignature → const Strategy
web3 coinbase signature strategy
web3MetamaskSignature → const Strategy
web3 metamask signature strategy
web3OkxWalletSignature → const Strategy
web3 okx wallet signature strategy