SessionTokenPollMode enum
SessionTokenPollMode manages how to refresh the sessionToken
- Inheritance
- Available extensions
- Annotations
-
- @Deprecated('SessionTokenPollMode has been deprecated. ' 'Use the AuthConfig.sessionTokenPolling boolean instead')
Values
- hungry → const SessionTokenPollMode
-
Hungry refresh: whenever token expires (more http access and power use)
- lazy → const SessionTokenPollMode
-
Lazy refresh: only as required (with possible increased latency on access)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SessionTokenPollMode> - A constant List of the values in this enum, in order of their declaration.