StringExtension extension
Extensions to the String class
- on
Properties
- b64decoded → String
-
Available on String, provided by the StringExtension extension
Decode a String that has been base64 encodedno setter - initials → String
-
Available on String, provided by the StringExtension extension
Return a String comprising all alphanumeric first characters of space-delimited words in the string, upper casedno setter - orNullIfEmpty → String?
-
Available on String, provided by the StringExtension extension
A version of the String which is null if emptyno setter
Methods
-
camelToSentenceCase(
) → String -
Available on String, provided by the StringExtension extension
Convert a camel case string to a sentence case string